@@ -304,6 +304,9 @@ enum litest_device_type {
 	LITEST_ELAN_TABLET,
 	LITEST_ABSINFO_OVERRIDE,
 	LITEST_TABLET_MODE_UNRELIABLE,
+	LITEST_KEYBOARD_LOGITECH_MEDIA_KEYBOARD_ELITE,
+	LITEST_SONY_VAIO_KEYS,
+	LITEST_SYNAPTICS_PRESSUREPAD,
 };
 
 #define LITEST_DEVICELESS	-2
